==> estateplat-common-1.1.0-20160805.025715-142-sources.jar: cn/gtmap/estateplat/model/server/core/BdcYg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 不动产预告登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_yg")
public class BdcYg extends QllxParent implements QllxVo{
    /*@Id
    private String qlid;//权利Id
    private String bdcdyid;//不动产单元Id*/
    private String ygdjzl;//预告登记种类
    private String tdqlr;//土地权利人
    //zdd 读取不动产单元的定着物用途
    private String ghyt;//规划用途
    private String fwxz;//房屋性质
    private Double jzmj;//建筑面积
    private Double qdjg;//建筑面积取得价格/被担保主债权数额
    private String mjdw;//单位

    private String ywh;
    private String qllx;//权利类型
    /*private String proid;//项目ID*/
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记

    private Integer qszt;//权属状态
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间
    private Date zwlxksqx;//债务履行开始期限
    private Date zwlxjsqx;//债务履行结束期限

    private Integer szc;//所在层
    private Integer zcs;//总层数
    private Integer wlc;//物理层

    private String jyhth;//交易合同号

    private Double jyje;//交易金额

    private String qt;//其他
    private String szmyc;//所在名义层
    private Double fttdmj;//分摊土地面积


    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getJyhth() {
        return jyhth;
    }

    public void setJyhth(String jyhth) {
        this.jyhth = jyhth;
    }

    public Double getJyje() {
        return jyje;
    }

    public void setJyje(Double jyje) {
        this.jyje = jyje;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }


    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }



    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public String getYgdjzl() {
        return ygdjzl;
    }

    public void setYgdjzl(String ygdjzl) {
        this.ygdjzl = ygdjzl;
    }

    public String getTdqlr() {
        return tdqlr;
    }

    public void setTdqlr(String tdqlr) {
        this.tdqlr = tdqlr;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }


    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }


    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Date getZwlxksqx() {
        return zwlxksqx;
    }

    public void setZwlxksqx(Date zwlxksqx) {
        this.zwlxksqx = zwlxksqx;
    }

    public Date getZwlxjsqx() {
        return zwlxjsqx;
    }

    public void setZwlxjsqx(Date zwlxjsqx) {
        this.zwlxjsqx = zwlxjsqx;
    }

    public Integer getSzc() {
        return szc;
    }

    public void setSzc(Integer szc) {
        this.szc = szc;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public String getSzmyc() {
        return szmyc;
    }

    public void setSzmyc(String szmyc) {
        this.szmyc = szmyc;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Integer getWlc() {
        return wlc;
    }

    public void setWlc(Integer wlc) {
        this.wlc = wlc;
    }
}

==> estateplat-common-1.1.0-20160822.123620-164-sources.jar: cn/gtmap/estateplat/model/server/core/BdcYg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 不动产预告登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_yg")
public class BdcYg extends QllxParent implements QllxVo{
    /*@Id
    private String qlid;//权利Id
    private String bdcdyid;//不动产单元Id*/
    private String ygdjzl;//预告登记种类
    private String tdqlr;//土地权利人
    //zdd 读取不动产单元的定着物用途
    private String ghyt;//规划用途
    private String fwxz;//房屋性质
    private Double jzmj;//建筑面积
    private Double qdjg;//建筑面积取得价格/被担保主债权数额
    private String mjdw;//单位

    private String ywh;
    private String qllx;//权利类型
    /*private String proid;//项目ID*/
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记

    private Integer qszt;//权属状态
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间
    private Date zwlxksqx;//债务履行开始期限
    private Date zwlxjsqx;//债务履行结束期限

    private Integer szc;//所在层
    private Integer zcs;//总层数
    private Integer wlc;//物理层

    private String jyhth;//交易合同号

    private Double jyje;//交易金额

    private String qt;//其他
    private String szmyc;//所在名义层
    private Double fttdmj;//分摊土地面积
    private Date tdsyksqx;//土地使用开始期限
    private Date tdsyjsqx;//土地使用结束期限


    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getJyhth() {
        return jyhth;
    }

    public void setJyhth(String jyhth) {
        this.jyhth = jyhth;
    }

    public Double getJyje() {
        return jyje;
    }

    public void setJyje(Double jyje) {
        this.jyje = jyje;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }


    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }



    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public String getYgdjzl() {
        return ygdjzl;
    }

    public void setYgdjzl(String ygdjzl) {
        this.ygdjzl = ygdjzl;
    }

    public String getTdqlr() {
        return tdqlr;
    }

    public void setTdqlr(String tdqlr) {
        this.tdqlr = tdqlr;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }


    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }


    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Date getZwlxksqx() {
        return zwlxksqx;
    }

    public void setZwlxksqx(Date zwlxksqx) {
        this.zwlxksqx = zwlxksqx;
    }

    public Date getZwlxjsqx() {
        return zwlxjsqx;
    }

    public void setZwlxjsqx(Date zwlxjsqx) {
        this.zwlxjsqx = zwlxjsqx;
    }

    public Integer getSzc() {
        return szc;
    }

    public void setSzc(Integer szc) {
        this.szc = szc;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public String getSzmyc() {
        return szmyc;
    }

    public void setSzmyc(String szmyc) {
        this.szmyc = szmyc;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Integer getWlc() {
        return wlc;
    }

    public void setWlc(Integer wlc) {
        this.wlc = wlc;
    }

    public Date getTdsyksqx() {
        return tdsyksqx;
    }

    public void setTdsyksqx(Date tdsyksqx) {
        this.tdsyksqx = tdsyksqx;
    }

    public Date getTdsyjsqx() {
        return tdsyjsqx;
    }

    public void setTdsyjsqx(Date tdsyjsqx) {
        this.tdsyjsqx = tdsyjsqx;
    }
}
